library(testthat,quietly=TRUE)
library(growcurves,quietly=TRUE)

test_check("growcurves")